@@ -1,8 +1,8 @@
 //! Handler future types.
 
 use crate::response::Response;
+use axum_core::extract::Request;
 use futures_util::future::Map;
-use http::Request;
 use pin_project_lite::pin_project;
 use std::{convert::Infallible, future::Future, pin::Pin, task::Context};
 use tower::util::Oneshot;
@@ -19,29 +19,29 @@ opaque_future! {
 
 pin_project! {
     /// The response future for [`Layered`](super::Layered).
-    pub struct LayeredFuture<S, ReqBody>
+    pub struct LayeredFuture<S>
     where
-        S: Service<Request<ReqBody>>,
+        S: Service<Request>,
     {
         #[pin]
-        inner: Map<Oneshot<S, Request<ReqBody>>, fn(Result<S::Response, S::Error>) -> Response>,
+        inner: Map<Oneshot<S, Request>, fn(Result<S::Response, S::Error>) -> Response>,
     }
 }
 
-impl<S, ReqBody> LayeredFuture<S, ReqBody>
+impl<S> LayeredFuture<S>
 where
-    S: Service<Request<ReqBody>>,
+    S: Service<Request>,
 {
     pub(super) fn new(
-        inner: Map<Oneshot<S, Request<ReqBody>>, fn(Result<S::Response, S::Error>) -> Response>,
+        inner: Map<Oneshot<S, Request>, fn(Result<S::Response, S::Error>) -> Response>,
     ) -> Self {
         Self { inner }
     }
 }
 
-impl<S, ReqBody> Future for LayeredFuture<S, ReqBody>
+impl<S> Future for LayeredFuture<S>
 where
-    S: Service<Request<ReqBody>>,
+    S: Service<Request>,
 {
     type Output = Response;
 
